==> zio-aws-rds_2.13-5.17.295.11-sources.jar: zio/aws/rds/model/ServerlessV2ScalingConfigurationInfo.scala <==
package zio.aws.rds.model
import zio.aws.rds.model.primitives.DoubleOptional
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ServerlessV2ScalingConfigurationInfo(
    minCapacity: Optional[DoubleOptional] = Optional.Absent,
    maxCapacity: Optional[DoubleOptional] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.ServerlessV2ScalingConfigurationInfo = {
    import ServerlessV2ScalingConfigurationInfo.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.ServerlessV2ScalingConfigurationInfo
      .builder()
      .optionallyWith(minCapacity.map(value => value: java.lang.Double))(
        _.minCapacity
      )
      .optionallyWith(maxCapacity.map(value => value: java.lang.Double))(
        _.maxCapacity
      )
      .build()
  }
  def asReadOnly
      : zio.aws.rds.model.ServerlessV2ScalingConfigurationInfo.ReadOnly =
    zio.aws.rds.model.ServerlessV2ScalingConfigurationInfo.wrap(buildAwsValue())
}
object ServerlessV2ScalingConfigurationInfo {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.ServerlessV2ScalingConfigurationInfo
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.ServerlessV2ScalingConfigurationInfo =
      zio.aws.rds.model.ServerlessV2ScalingConfigurationInfo(
        minCapacity.map(value => value),
        maxCapacity.map(value => value)
      )
    def minCapacity: Optional[DoubleOptional]
    def maxCapacity: Optional[DoubleOptional]
    def getMinCapacity: ZIO[Any, AwsError, DoubleOptional] =
      AwsError.unwrapOptionField("minCapacity", minCapacity)
    def getMaxCapacity: ZIO[Any, AwsError, DoubleOptional] =
      AwsError.unwrapOptionField("maxCapacity", maxCapacity)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.ServerlessV2ScalingConfigurationInfo
  ) extends zio.aws.rds.model.ServerlessV2ScalingConfigurationInfo.ReadOnly {
    override val minCapacity: Optional[DoubleOptional] = zio.aws.core.internal
      .optionalFromNullable(impl.minCapacity())
      .map(value => value: DoubleOptional)
    override val maxCapacity: Optional[DoubleOptional] = zio.aws.core.internal
      .optionalFromNullable(impl.maxCapacity())
      .map(value => value: DoubleOptional)
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.ServerlessV2ScalingConfigurationInfo
  ): zio.aws.rds.model.ServerlessV2ScalingConfigurationInfo.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-rds_3-5.17.196.1-sources.jar: zio/aws/rds/model/ServerlessV2ScalingConfigurationInfo.scala <==
package zio.aws.rds.model
import zio.aws.rds.model.primitives.DoubleOptional
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ServerlessV2ScalingConfigurationInfo(
    minCapacity: Optional[DoubleOptional] = Optional.Absent,
    maxCapacity: Optional[DoubleOptional] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.ServerlessV2ScalingConfigurationInfo = {
    import ServerlessV2ScalingConfigurationInfo.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.ServerlessV2ScalingConfigurationInfo
      .builder()
      .optionallyWith(minCapacity.map(value => value: java.lang.Double))(
        _.minCapacity
      )
      .optionallyWith(maxCapacity.map(value => value: java.lang.Double))(
        _.maxCapacity
      )
      .build()
  }
  def asReadOnly
      : zio.aws.rds.model.ServerlessV2ScalingConfigurationInfo.ReadOnly =
    zio.aws.rds.model.ServerlessV2ScalingConfigurationInfo.wrap(buildAwsValue())
}
object ServerlessV2ScalingConfigurationInfo {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.ServerlessV2ScalingConfigurationInfo
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.ServerlessV2ScalingConfigurationInfo =
      zio.aws.rds.model.ServerlessV2ScalingConfigurationInfo(
        minCapacity.map(value => value),
        maxCapacity.map(value => value)
      )
    def minCapacity: Optional[DoubleOptional]
    def maxCapacity: Optional[DoubleOptional]
    def getMinCapacity: ZIO[Any, AwsError, DoubleOptional] =
      AwsError.unwrapOptionField("minCapacity", minCapacity)
    def getMaxCapacity: ZIO[Any, AwsError, DoubleOptional] =
      AwsError.unwrapOptionField("maxCapacity", maxCapacity)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.ServerlessV2ScalingConfigurationInfo
  ) extends zio.aws.rds.model.ServerlessV2ScalingConfigurationInfo.ReadOnly {
    override val minCapacity: Optional[DoubleOptional] = zio.aws.core.internal
      .optionalFromNullable(impl.minCapacity())
      .map(value => value: DoubleOptional)
    override val maxCapacity: Optional[DoubleOptional] = zio.aws.core.internal
      .optionalFromNullable(impl.maxCapacity())
      .map(value => value: DoubleOptional)
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.ServerlessV2ScalingConfigurationInfo
  ): zio.aws.rds.model.ServerlessV2ScalingConfigurationInfo.ReadOnly =
    new Wrapper(impl)
}
